@@ -1,4 +1,4 @@
-# last modified 2014-08-09 by J. Fox
+# last modified 2014-09-26 by J. Fox
 #  applied patch to improve window behaviour supplied by Milan Bouchet-Valat 2011-09-22
 
 .onAttach <- function(...){
@@ -28,7 +28,7 @@
     save.options <- options(warn=-1)
     on.exit(options(save.options))
     required.packages <- rev(c("abind", "aplpack", "car", "colorspace", 
-        "effects", "e1071", "foreign", "grid", "Hmisc", "knitr", "lattice", "leaps", "lmtest",
+        "effects", "e1071", "foreign", "Hmisc", "knitr", "lattice", "leaps", "lmtest",
         "markdown", "MASS", "mgcv", "multcomp", "nlme", "nnet", "RcmdrMisc", "relimp", "rgl",
         "sandwich", "sem"))
     if (WindowsP()) required.packages <- c(required.packages, c("RODBC", "XLConnect"))
